translate.filters.spelling

Package translate :: Package filters :: Module spelling |
[hide private]
[frames] | no frames]

# Module spelling

source code

An API to provide spell checking for use in checks or elsewhere.

Functions | [hide private]
check(text, lang) | source code

Variables | [hide private]
| available = `True` hash(x)
| checkers = ``{``}``
| __package__ = ``'``translate.filters``'``

Imports: sys, checker, DictNotFoundError, EnchantError